@@ -1,11 +1,8 @@
 #### Symmetric Sparse Matrices in compressed column-oriented format
 
 setAs("dgCMatrix", "dsCMatrix",
-      function(from) {
-	  if(!exists(".warn.dsC")) { ## now only warn *once* ..
-	      warning("as(.,\"dsCMatrix\") is deprecated; do use as(., \"symmetricMatrix\")")
-	      assign(".warn.dsC", "DONE", envir = .GlobalEnv)
-	  }
+      function(from) { ## r2130 ... | 2008-03-14 | added deprecation warning
+	  warning("as(.,\"dsCMatrix\") is deprecated (since 2008); do use as(., \"symmetricMatrix\")")
 	  as(from, "symmetricMatrix")
       })
 
@@ -44,6 +41,20 @@ setAs("dsCMatrix", "dgCMatrix",
 setAs("dsCMatrix", "dsyMatrix",
       function(from) as(from, "denseMatrix"))
 
+##' Check if \code{name} (== "[sS][pP][dD]Cholesky") fits the values of the
+##' logicals (perm, LDL, super).
+##' @param name a string such as "sPdCholesky"
+##' @param perm also known as \code{pivot}
+##' @param LDL
+##' @param super
+##' @return logical: TRUE if the name matches
+.chkName.CHM <- function(name, perm, LDL, super)
+    .Call(R_chkName_Cholesky, name, perm, LDL, super)
+## ../src/dsCMatrix.c
+
+.CHM.factor.name <- function(perm, LDL, super)
+    .Call(R_chm_factor_name, perm, LDL, super)
+
 ## have rather tril() and triu() methods than
 ## setAs("dsCMatrix", "dtCMatrix", ....)
 setMethod("tril", "dsCMatrix",
@@ -64,63 +75,67 @@ setMethod("triu", "dsCMatrix",
 	      else triu(as(x, "dgCMatrix"), k = k, ...)
 	  })
 
-solve.dsC.mat <- function(a,b, tol) {
-    r <- tryCatch(.Call(dsCMatrix_matrix_solve, a, b),
+solve.dsC.mat <- function(a,b, LDL = NA, tol = .Machine$double.eps) {
+    r <- tryCatch(.Call(dsCMatrix_matrix_solve, a, b, LDL),
 		  error=function(e)NULL, warning=function(w)NULL)
     if(is.null(r)) { ## cholmod factorization was not ok
-	Matrix.msg("Cholmod Cholesky factorization was unsuccessful --> using LU")
-	if(missing(tol) || is.na(tol)) tol <- 1.# special "code" for 'order := 2' in C
-	e.a <- expand(lu.a <- LU.dgC(as(a,"dgCMatrix"), tol=tol, errSing=TRUE))
-	##  A = PLU  <--> A^{-1} x = U^-1 L^-1 P x
-	solve(e.a$U, solve(e.a$L, b[lu.a@p + 1L,]))
+	Matrix.msg("solve.dsC.mat(): Cholmod factorization unsuccessful --> using LU(<dgC>)")
+	.solve.dgC.lu(as(a,"dgCMatrix"), b=b, tol=tol)
     }
     else r
 }
 
+## ``Fully-sparse'' solve()  {different Cholmod routine, otherwise "the same"}:
+solve.dsC.dC <- function(a,b, LDL = NA, tol = .Machine$double.eps) {
+    r <- tryCatch(.Call(dsCMatrix_Csparse_solve, a, b, LDL),
+		  error=function(e)NULL, warning=function(w)NULL)
+    if(is.null(r)) { ## cholmod factorization was not ok
+	Matrix.msg("solve.dsC.dC(): Cholmod factorization unsuccessful --> using LU(<dgC>)")
+	.solve.dgC.lu(as(a,"dgCMatrix"), b=b, tol=tol)
+    }
+    else r
+}
+
+## <sparse> . <dense> ------------------------
+
 setMethod("solve", signature(a = "dsCMatrix", b = "ddenseMatrix"),
-	  function(a, b, ...) {
-	      if (class(b) != "dgeMatrix")
-		  b <- .Call(dup_mMatrix_as_dgeMatrix, b)
-	      solve.dsC.mat(a,b)
+	  function(a, b, LDL = NA, tol = .Machine$double.eps, ...) {
+	      solve.dsC.mat(a, b = if(!is(b, "dgeMatrix")) ..2dge(b) else b,
+			    LDL=LDL, tol=tol)
 	  },
 	  valueClass = "dgeMatrix")
 setMethod("solve", signature(a = "dsCMatrix", b = "denseMatrix"),
 	  ## only triggers for diagonal*, ldense*.. (but *not* ddense: above)
-	  function(a, b, ...)
-	  solve.dsC.mat(a, as(.Call(dup_mMatrix_as_geMatrix, b), "dgeMatrix")))
+	  function(a, b, LDL = NA, tol = .Machine$double.eps, ...)
+	  solve.dsC.mat(a, as(.Call(dup_mMatrix_as_geMatrix, b), "dgeMatrix"),
+			LDL=LDL, tol=tol))
 
 setMethod("solve", signature(a = "dsCMatrix", b = "matrix"),
-	  function(a, b, ...)
-	  solve.dsC.mat(a, .Call(dup_mMatrix_as_dgeMatrix, b)),
+	  function(a, b, LDL = NA, tol = .Machine$double.eps, ...)
+	  solve.dsC.mat(a, ..2dge(b), LDL=LDL, tol=tol),
 	  valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dsCMatrix", b = "numeric"),
-	  function(a, b, ...)
-	  solve.dsC.mat(a, .Call(dup_mMatrix_as_dgeMatrix, b)),
+	  function(a, b, LDL = NA, tol = .Machine$double.eps, ...)
+	  solve.dsC.mat(a, ..2dge(b), LDL=LDL, tol=tol),
 	  valueClass = "dgeMatrix")
 
-## `` Fully-sparse'' solve() :
-solve.dsC.dsC <- function(a,b, tol) {
-    r <- tryCatch(.Call(dsCMatrix_Csparse_solve, a, b),
-		  error=function(e)NULL, warning=function(w)NULL)
-    if(is.null(r)) { ## cholmod factorization was not ok
-	Matrix.msg("Cholmod Cholesky factorization was unsuccessful --> using LU")
-	if(missing(tol) || is.na(tol)) tol <- 1.# special "code" for 'order := 2' in C
-	e.a <- expand(lu.a <- LU.dgC(as(a,"dgCMatrix"), tol=tol, errSing=TRUE))
-	##  A = PLU  <--> A^{-1} x = U^-1 L^-1 P x
-	solve(e.a$U, solve(e.a$L, b[lu.a@p + 1L,]))
-    }
-    else r
-}
+## <sparse> . <sparse> ------------------------
+
 setMethod("solve", signature(a = "dsCMatrix", b = "dsparseMatrix"),
-	  function(a, b, ...) {
-	      if (!is(b, "CsparseMatrix"))
-		  b <- as(b, "CsparseMatrix")
-	      if (is(b, "symmetricMatrix")) ## not supported (yet) by cholmod_spsolve
+	  function(a, b, LDL = NA, tol = .Machine$double.eps, ...) {
+	      cb <- getClassDef(class(b))
+	      if (!extends(cb, "CsparseMatrix"))
+		  cb <- getClassDef(class(b <- as(b, "CsparseMatrix")))
+	      if (extends(cb, "symmetricMatrix")) ## not supported (yet) by cholmod_spsolve
 		  b <- as(b, "dgCMatrix")
-	      solve.dsC.dsC(a,b)
+	      solve.dsC.dC(a,b, LDL=LDL, tol=tol)
 	  })
 
+setMethod("solve", signature(a = "dsCMatrix", b = "missing"),
+	  function(a, b, ...) solve(a, .trDiagonal(nrow(a), unitri=FALSE), ...))
+
+
 
 setMethod("chol", signature(x = "dsCMatrix"),
 	  function(x, pivot = FALSE, ...) .Call(dsCMatrix_chol, x, pivot),
@@ -139,13 +154,16 @@ setMethod("t", signature(x = "dsCMatrix"),
 
 ### These two are very similar, the first one has the advantage to be applicable to 'Chx' directly:
 
+## "used" currently only in ../tests/factorizing.R
 .diag.dsC <- function(x, Chx = Cholesky(x, LDL=TRUE), res.kind = "diag") {
     force(Chx)
     if(!missing(Chx)) stopifnot(.isLDL(Chx), is.integer(Chx@p), is.double(Chx@x))
-    .Call(diag_tC, Chx@p, Chx@x, Chx@perm, res.kind)
+    .Call(diag_tC, Chx, res.kind)
     ##    ^^^^^^^ from ../src/Csparse.c
+    ## => res.kind in ("trace", "sumLog", "prod", "min", "max", "range", "diag", "diagBack")
 }
 
+## nowhere used/tested (FIXME?)
 ## here, we  *could* allow a 'mult = 0' factor :
 .CHM.LDL.D <- function(x, perm = TRUE, res.kind = "diag") {
     .Call(dsCMatrix_LDL_D, x, perm, res.kind)
@@ -166,7 +184,7 @@ ldet1.dsC <- function(x, ...) .Call(CHMfactor_ldetL2, Cholesky(x, ...))
 ## these are slightly faster (ca. 3 to 4 %):
 ldet2.dsC <- function(x, ...) {
     Ch <- Cholesky(x, super = FALSE, ...)
-    .Call(diag_tC, Ch@p, Ch@x, Ch@perm, "sumLog")
+    .Call(diag_tC, Ch, "sumLog")
 }
 ## only very slightly ( ~ < 1% ) faster (than "ldet2"):
 ldet3.dsC <- function(x, perm = TRUE)
@@ -178,7 +196,7 @@ setMethod("determinant", signature(x = "dsCMatrix", logarithm = "missing"),
 setMethod("determinant", signature(x = "dsCMatrix", logarithm = "logical"),
 	  function(x, logarithm, ...)
       {
-	  if((n <- x@Dim[1]) <= 1)
+	  if(x@Dim[1] <= 1L)
 	      return(mkDet(diag(x), logarithm))
 	  Chx <- tryCatch(suppressWarnings(Cholesky(x, LDL=TRUE)),
                           error = function(e) NULL)
@@ -191,7 +209,7 @@ setMethod("determinant", signature(x = "dsCMatrix", logarithm = "logical"),
           if(is.null(Chx))  ## we do *not* have a positive definite matrix
 	      detSparseLU(x, logarithm)
 	  else {
-              d <- .Call(diag_tC, Chx@p, Chx@x, Chx@perm, res.kind = "diag")
+              d <- .Call(diag_tC, Chx, res.kind = "diag")
 	      mkDet(d, logarithm=logarithm)
           }
       })
