@@ -1,7 +1,7 @@
 #  File src/library/tools/R/parseLatex.R
-#  Part of the R package, http://www.R-project.org
+#  Part of the R package, https://www.R-project.org
 #
-#  Copyright (C) 1995-2014 The R Core Team
+#  Copyright (C) 1995-2017 The R Core Team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,9 +14,10 @@
 #  GNU General Public License for more details.
 #
 #  A copy of the GNU General Public License is available at
-#  http://www.r-project.org/Licenses/
+#  https://www.R-project.org/Licenses/
 
-## this is called during package installation via makeLatex()
+## This is called during package installation via makeLatex()
+## so we can't use the symbol C_parseLatex here
 parseLatex <- function(text, filename = deparse(substitute(text)),
                      verbose = FALSE, verbatim = c("verbatim", "verbatim*",
                      "Sinput", "Soutput") )
@@ -24,7 +25,7 @@ parseLatex <- function(text, filename = deparse(substitute(text)),
     ## the internal function must get some sort of srcfile
     srcfile <- srcfilecopy(filename, text, file.mtime(filename))
     text <- paste(text, collapse="\n")
-    .External2("C_parseLatex", text, srcfile, verbose, as.character(verbatim),
+    .External2("parseLatex", text, srcfile, verbose, as.character(verbatim),
                PACKAGE = "tools")
 }
 
@@ -106,6 +107,10 @@ latexToUtf8 <- function(x)
 			    k <- k+1L
 			},
 			COMMENT = getNext <- TRUE, # strip comments
+			MACRO = { # Something like \'\i; assume 2nd macro has no args
+			    args[[k]] <- nextobj
+			    k <- k+1L
+			},
 			BLOCK =,
 			ENVIRONMENT =,
 			MATH = {
