@@ -1,7 +1,7 @@
 #  File src/library/utils/R/frametools.R
-#  Part of the R package, http://www.R-project.org
+#  Part of the R package, https://www.R-project.org
 #
-#  Copyright (C) 1995-2012 The R Core Team
+#  Copyright (C) 1995-2015 The R Core Team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,11 +14,11 @@
 #  GNU General Public License for more details.
 #
 #  A copy of the GNU General Public License is available at
-#  http://www.r-project.org/Licenses/
+#  https://www.R-project.org/Licenses/
 
 stack <- function(x, ...) UseMethod("stack")
 
-stack.data.frame <- function(x, select, ...)
+stack.data.frame <- function(x, select, drop=FALSE, ...)
 {
     if (!missing(select)) {
 	nl <- as.list(1L:ncol(x))
@@ -31,21 +31,28 @@ stack.data.frame <- function(x, select, ...)
     if(!all(keep))
         warning("non-vector columns will be ignored")
     x <- x[, keep, drop = FALSE]
-    ## need to avoid promotion to factors
+    ind <- rep(factor(names(x), unique(names(x))), lengths(x))
+    if (drop) {
+        ind <- droplevels(ind)
+    }
     data.frame(values = unlist(unname(x)),
-               ind = factor(rep.int(names(x), lapply(x, length))),
+               ind,
                stringsAsFactors = FALSE)
 }
 
-stack.default <- function(x, ...)
+stack.default <- function(x, drop=FALSE, ...)
 {
     x <- as.list(x)
     keep <- unlist(lapply(x, is.vector))
     if(!sum(keep)) stop("at least one vector element is required")
     if(!all(keep)) warning("non-vector elements will be ignored")
     x <- x[keep]
+    ind <- rep(factor(names(x), unique(names(x))), lengths(x))
+    if (drop) {
+        ind <- droplevels(ind)
+    }
     data.frame(values = unlist(unname(x)),
-               ind = factor(rep.int(names(x), lapply(x, length))),
+               ind,
                stringsAsFactors = FALSE)
 }
 
@@ -57,7 +64,7 @@ unstack.data.frame <- function(x, form, ...)
     if (length(form) < 3)
         stop("'form' must be a two-sided formula")
     res <- c(tapply(eval(form[[2L]], x), eval(form[[3L]], x), as.vector))
-    if (length(res) >= 2L && any(diff(unlist(lapply(res, length))) != 0L))
+    if (length(res) >= 2L && any(diff(lengths(res)) != 0L))
         return(res)
     data.frame(res, stringsAsFactors = FALSE)
 }
@@ -69,7 +76,7 @@ unstack.default <- function(x, form, ...)
     if ((length(form) < 3) || (length(all.vars(form))>2))
         stop("'form' must be a two-sided formula with one term on each side")
     res <- c(tapply(eval(form[[2L]], x), eval(form[[3L]], x), as.vector))
-    if (length(res) >= 2L && any(diff(unlist(lapply(res, length))) != 0L))
+    if (length(res) >= 2L && any(diff(lengths(res)) != 0L))
         return(res)
     data.frame(res, stringsAsFactors = FALSE)
 }
