@@ -964,10 +964,12 @@ static void WriteItem (SEXP s, SEXP ref_table, R_outpstream_t stream)
     int i;
     SEXP t;
 
-    if (R_compile_pkgs && TYPEOF(s) == CLOSXP && TYPEOF(BODY(s)) != BCODESXP) {
+    if (R_compile_pkgs && TYPEOF(s) == CLOSXP && TYPEOF(BODY(s)) != BCODESXP &&
+        !R_disable_bytecode) {
+
 	SEXP new_s;
 	R_compile_pkgs = FALSE;
-	PROTECT(new_s = R_cmpfun(s));
+	PROTECT(new_s = R_cmpfun1(s));
 	WriteItem (new_s, ref_table, stream);
 	UNPROTECT(1);
 	R_compile_pkgs = TRUE;
@@ -1564,7 +1566,7 @@ static SEXP ReadItem (SEXP ref_table, R_inpstream_t stream)
 	R_ReadItemDepth++;
 	PROTECT(s = ReadItem(ref_table, stream)); /* print name */
 	R_ReadItemDepth--;
-	s = installChar(s);
+	s = installTrChar(s);
 	AddReadRef(ref_table, s);
 	UNPROTECT(1);
 	return s;
@@ -1783,6 +1785,8 @@ static SEXP ReadItem (SEXP ref_table, R_inpstream_t stream)
 	    R_ReadItemDepth--;
 	}
 	UNPROTECT(1); /* s */
+	if (TYPEOF(s) == BCODESXP && !R_BCVersionOK(s))
+	    return R_BytecodeExpr(s);
 	return s;
     }
 }
@@ -1876,10 +1880,12 @@ static SEXP ReadBC1(SEXP ref_table, SEXP reps, R_inpstream_t stream)
     R_ReadItemDepth++;
     SETCAR(s, ReadItem(ref_table, stream)); /* code */
     R_ReadItemDepth--;
-    SETCAR(s, R_bcEncode(CAR(s)));
+    SEXP bytes = PROTECT(CAR(s));
+    SETCAR(s, R_bcEncode(bytes));
     SETCDR(s, ReadBCConsts(ref_table, reps, stream)); /* consts */
     SET_TAG(s, R_NilValue); /* expr */
-    UNPROTECT(1);
+    R_registerBC(bytes, s);
+    UNPROTECT(2);
     return s;
 }
 
@@ -2764,7 +2770,7 @@ static SEXP R_getVarsFromFrame(SEXP vars, SEXP env, SEXP forcesxp)
     len = LENGTH(vars);
     PROTECT(val = allocVector(VECSXP, len));
     for (i = 0; i < len; i++) {
-	sym = installChar(STRING_ELT(vars, i));
+	sym = installTrChar(STRING_ELT(vars, i));
 
 	tmp = findVarInFrame(env, sym);
 	if (tmp == R_UnboundValue) {
